Node

Struct Node 

pub struct Node {
    pub id: NodeId,
    pub op: OpKind,
    pub inputs: Vec<NodeId>,
    pub shape: Vec<usize>,
}
Struct for a graph node in the ML operations sequence.

They are constructed automatically by interacting with operations in a crate::graph::Graph struct.

Each node represents a particular action as determined by the OpKind field.

Examples

#TODO

Fields

id: NodeId

ID of the current node.

This is automatically generated on Node creation.

op: OpKind

Operation of the current node in the ML pipeline. See OpKind.

inputs: Vec<NodeId>

Node IDs of the inputs to this operation.

shape: Vec<usize>

Tensor dimensions (shape) of the output tensor produced by this node.